# Extract Agent Package Contents

1. Copy this package to a target system

2. Extract the contents of the package tarball into a location your JVM can
access using the tar extraction utility. For example:

   ```
   $ tar -xvf $#package-filename#
   ```

Note: the notional variable `AGENT_HOME` is a convention used throughout the
install instructions to refer to the `wily` directory under
where the Agent package was extracted. For example if
`$#package-filename#` was extracted in `/opt/`, `AGENT_HOME`
value would be `/opt/wily`.

# Instrument any Java Application

1. Add this at the beginning of your JVM command line arguments:

   * For Application using Java 8 and previous versions:
   
   ```
   -javaagent:$AGENT_HOME/Agent.jar
   ```
        
   * For Application using Java 9 and higher versions:

   ```
   -javaagent:$AGENT_HOME/Agent.jar --add-exports java.instrument/sun.instrument=ALL-UNNAMED --add-exports jdk.management/com.sun.management.internal=ALL-UNNAMED --patch-module java.base=$AGENT_HOME/releases/<release_number>/common/AgentSocket.jar
   ```

2. Restart the JVM.

The install instructions and configuration instructions for extensions can also be found in the `installInstructions.md` file in the downloaded archive.
---
# Set Enterprise Manager Connection Properties

Specify the Enterprise Manager host and port as properties on the
application start-up command, e.g.

	-DagentManager.url.1={EMHost}:{EMPort}
---
# muleesb (11.1.4.13)
# Mule Esb Monitoring

## Description
Mule ESB is a lightweight Java-based enterprise service bus (ESB) and integration platform that allows developers to connect applications together quickly and easily, enabling them to exchange data. Mule ESB enables easy integration of existing systems, regardless of the different technologies that the applications use, including JMS, Web Services, JDBC, HTTP, and more. The key advantage of an ESB is that it allows different applications to communicate with each other by acting as a transit system for carrying data between applications within your enterprise or across the Internet.

# Installation Instructions
Mule extension is part of the default agent installer, no additional steps are needed.
## Usage Instructions
The Mule ESB is structured into three main areas driven by defined "Flow" The monitoring solution extension provides visibility into the Transport Layer, Integration Layer and Application Layer visualizing the invocation elements by individual Flows.

          
### Inbound HTTP Traffic

* HTTP Endpoint ( Mule 3.6 and higher) : 
 The monitoring solution aligns with the standard CA APM features and visualizes inbound HTTP traffic via SOAP or Restful Web Services in the Frontend node in the investigator. The Apps metric path item is replaced with the name 
 or identification of the deployed Mule ESB application. The URI section, if not configured different (configuration section) is formatted with the defined URI of the HTTP Listener configuration. 
 'Frontends|Apps|{mule-application-name}' and 
 'Frontends|Apps|{mule-application-name}|URLs|{URI defined in Mule HTTP Listener}'
  		  	
* Mule ESB 3.3.0 HTTP Message Receiver Support : 
  The usage of the deprecated older HTTP Message Receiver is still supported. Metrics are visualized different on this HTTP Message Receiver component. The App node in the metric path is replaced by the receiver name and the URLs path with the 
  initial HTTP listening flow name.
 'Frontends|Apps|{mule-http-receiver-name}' and 
 'Frontends|Apps|{mule-http-receiver-name}|URLs|{mule-flow-name}'
 
* CXF Inbound Web Services : 
  In addition to the inbound http frontend metrics, the mule esb extension also visualizes inbound Web Services calls under the Web Services node in the Investigator. The first part of the custom metric path contains the http request path and the 
  second any available soap action.
  'Webservices|Server|{http-request-path}' and 
  'Webservices|Server|{http-request-path}|{soap-action}'
  		

### Outbound HTTP requests
 For outbound HTTP requests, the monitoring solution leverages the Backends node identical to all other CA APM solutions. HTTP calls are shown with the formatting 'Backends|WebService at {protocol}_//{host}_{port}|Paths|{path}' where the path component is being replaced by the path element of the request URI.In addition to the standard metrics, the Mule monitoring extension creates the metric Async Invocation Time (ms) metric. The Async Invocation Time is computed based on the async communication behaviour for outbound HTTP calls. By measuring the HTTP Response in the request flow, CA APM can measure the time to establish a request (Async Invocation Time) and the total round trip / request - response time for a request (Average Response Time).The Transaction Trace visualization also differs because of the async nature of the requests.		


### HTTP request payload visualization
As a special feature, the monitoring solution visualizes the HTTP payload of all inbound and outbound requests including the response payload. The payload is visualized in the transaction trace on the root component of the correspondent process sending or receiving the call.Besides HTTP traffic monitoring, this solution provides inbound and outbound message processing coverage for all defined endpoints in the Mule Flow. 
   

### Flow Visualization

Flows are the main transactional processes inside the Mule ESB framework. The monitoring solution has a special coverage for Flows with additional metrics making it easier to understand the requests and showing detailed error and analysis 
information.Flows are visualized at the Mule|Flows node.

Flow usage Metrics : 
'Mule|Flows:Active Flow Instances'	- The number of active flow instances. Instances are usually active while in listening mode.
'Mule|Flows:Average Branch Processing Time (ms)' - The average total time spent on the flow for processing. 
'Mule|Flows:Branch Processings Per Interval' -	The number of branches processed for this flow per interval.
---
# automaticattributedecoration (11.1.4.13)

# Automatic Attribute Decoration
Automatic attribute decoration is the CA Application Performance Management extension for getting critical Agent information as attributes in ATC.

# Configuration
Configure the `bundle.properties` file to point to the JSON File which contains all the details about the attributes.Extension can be configured using either a single JSON file or configuring individual properties in bundle.properties.
Please refer documentation for details about configuration.All properties for this extension are cold.
---
# Simpleframework extension
There is no installation required. This extension is part of default agent installation.

# Simpleframework Monitoring
This extension fully supports handle operations displaying details like metrics, correlation and Team Center support.
* Whenever a new request is initiated, the Investigator in Introscope shows the metric under Backends. 
  * Metric "Backends|Simpleframework on 127.0.0.1 at {port}"

---
#  JSMPP extension
There is no installation required. This extension is part of default agent installation.
# JSMPP Monitoring
This extension fully supports JSMPP Session operations  displaying details like metrics, correlation and Team Center support.
* Whenever a new request is initiated, the Investigator in Introscope shows the metric under Backends. 
  * Metric "Backends|SMPP on {jsmpp_host} at {jsmpp_port}|{method name}"

---
## Description
The extension provides web service backend visibility where OkHttp is used as a client in web applications.


# Installation Instructions
There is no installation required. This comes as a part of default java agent.
---
#  Elasticsearch Server extension
There is no installation required. This extension is part of default agent installation.


# Elasticsearch Monitoring
This extension supports following Elasticsearch operations 
(namely get, index, update, delete, bulk request and search query) 
displaying details like metrics, correlation and Team Center support.
* Whenever a new request is initiated, the Investigator in Introscope shows the initiation as a metric under Backends. It contains the node and port values.
  * Metric "Backends|Elasticsearch at 127.0.0.1 on port 9300|Indices|{Index Name}|{Operation}"
---
#  Couchbase Server extension
There is no installation required. This extension is part of default agent installation.

# Couchbase Monitoring
This extension fully supports Couchbase operations (namely get, insert, update, replace and query) displaying details like metrics, correlation and Team Center support.
* Whenever a new request is initiated, the Investigator in Introscope shows the metric under Backends. It contains the bucket, node and port values.
  * Metric "Backends|Couchbase on 127.0.0.1 at 8091|{bucket name}| {method name}"

---
# springboot (11.1.4.13)

# Spring Boot Monitoring
The extension is a monitoring solution to provide extended visibility into Spring - Boot applications.

# Spring Boot Application Discovery
* The monitoring solution discovers requests to the Spring Boot Application by creating a Frontend metric in the Investigator using the classname of the Spring Boot Application definition.
* The correct Frontend name is used in the metric visualization as well as Transaction Traces and Team Center.
---
# springrabbitmq (11.1.4.13)

# Spring AMQP Rabbit MQ Monitoring
In addition to the core Introscope Agent capability of JMS monitoring, this monitoring extensions adds support for Spring AMQP based message handling for Rabbit MQ.
* Inbound Message Handling
  1. With the help of this extension,Introscope discovers inbound messages as request and transaction starting points.
  2. Introscope visualizes the inbound message and request start point as a Frontends|Messaging Services (onMessage)|Queue|{queue}.
* Outbound Message Handling
  1. Outbound messaging calls (Message Put) are shown at the Backends node in the Investigator.The Rabbit MQ and the detailed queue name for the outbound message.
  2. Metric "Backends|Messaging Services (outgoing)|Queue|{queue}".

---
# springmongo (11.1.4.13)

# Spring Mongo DB Monitoring
* This is a monitoring solution for Spring MongoDB API requests with full support of request details towards the Mongo DB instance.
* Introscope shows the calls to the MongoDB at the Backend node starting with "Mongo DB on {host} at {port}". 
* Further details are discovered request type, the related object to the request and if available, the request criteria.
---
# springasync (11.1.4.13)

# Spring Async Monitoring
This extension fully supports all types of Spring Async operations displaying details like metrics, correlation and Team Center support.
* Whenever a new Async Thread request is initiated, the Investigator in Introscope shows the initiation as a metric under Spring node with the name "Async Task Execution" in combination with the corresponding threading mechanism used by the application.
  * Metric "Spring|Async Task Execution|{classname}"
* The Thread which was initiated and is being executed visualizes its starting point as a Frontend Metric "Async-XYZ" while XYZ is replaced with the type of Thread execution used by the Framework
  * Metric "Frontend|Apps|Spring-Async|Default"

---
## Description

# Installation Instructions
---
# Other Bundle: Instrument any Java Application

1. Add this at the beginning of your JVM command line arguments:

        -javaagent:$AGENT_HOME/Agent.jar

2. Restart the JVM.
